==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/tr/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Bir kullanıcı web sitede öğe talebinden vazgeçti',
    'a_user_requested' => 'Bir kullanıcı websitede bir öğe talebinde bulundu',
    'accessory_name' => 'Aksesuar Adı:',
    'additional_notes' => 'Ek Notlar:',
    'admin_has_created' => 'Bir yönetici sizin için :web site\'de bir hesap oluşturdu.',
    'asset' => 'Varlık:',
    'asset_name' => 'Varlık Adı:',
    'asset_requested' => 'İstenen varlık',
    'asset_tag' => 'Varlık etiketi:',
    'assigned_to' => 'Atanmış',
    'best_regards' => 'En iyi dileklerimizle,',
    'canceled' => 'İptal edildi:',
    'checkin_date' => 'Giriş Tarihi:',
    'checkout_date' => 'Çıkış Tarihi:',
    'click_to_confirm' => 'Lütfen :hesabınızı: onaylamak için aşağıdaki linke tıklayınız:',
    'click_on_the_link_accessory' => 'Lütfen aşağıdaki bağlantıya tıklayarak aksesuar talebinizi onaylayın.',
    'click_on_the_link_asset' => 'Lütfen aşağıdaki bağlantıya tıklayarak varlık talebinizi onaylayın.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Mevcut miktar',
    'Days' => 'Günler',
    'days' => 'Günler',
    'expecting_checkin_date' => 'Beklenen Giriş Tarihi:',
    'expires' => 'Bitiş',
    'Expiring_Assets_Report' => 'Süresi Dolan Varlık Raporu.',
    'Expiring_Licenses_Report' => 'Süresi Dolan Lisans Raporu.',
    'hello' => 'Merhaba',
    'hi' => 'Merhaba',
    'i_have_read' => 'Okudum ve kullanım şartlarını ve bu varlığı kabul ediyorum.',
    'item' => 'Ürün:',
    'Item_Request_Canceled' => 'Talep İptal Edildi',
    'Item_Requested' => 'Varlık Talep Edildi',
    'link_to_update_password' => 'Şifrenizi güncellemek için aşağıdaki linke tıklayınız :web password:',
    'login_first_admin' => 'Yeni Snipe-IT Kurulumu oturum açma kimlik bilgilerini aşağıdaki gibidir. ',
    'login' => 'Giriş:',
    'Low_Inventory_Report' => 'Düşük Stok Raporu',
    'min_QTY' => 'Min. Miktar',
    'name' => 'Ad',
    'new_item_checked' => 'Yeni varlık altında kullanıma alındı, ayrıntıları aşağıdadır.',
    'password' => 'Parola:',
    'password_reset' => 'Parola Sıfırlama',

    'read_the_terms' => 'Aşağıdaki kullanım koşullarını okuyunuz.',
    'read_the_terms_and_click' => 'Aşağıdaki kullanım şartlarını okuyun ve okumak onaylamak için alt kısımdaki linke tıklayınız
                         ve kullanım şartlarını kabul ve varlık aldık.',
    'requested' => 'Talep Edilen:',
    'reset_link' => 'Parola Sıfırlama Bağlantısı',
    'reset_password' => 'Şifrenizi sıfırlamak için burayı tıklatın:',
    'serial' => 'Seri',
    'supplier' => 'Tedarikçi',
    'tag' => 'Etiket',
    'test_email' => 'Snipe-It Test Maili',
    'test_mail_text' => 'Snipe-IT varlık yönetim sisteminden bir denemedir',
    'the_following_item' => 'Aşağıdaki varlık geri alındı olarak işaretlendi: ',
    'low_inventory_alert' => 'Şu var: Minimum envanterin altında olan veya yakında düşük olacak olan sayı maddesi. | Şunlar var: Minimum envanterin altında olan veya yakında olacak olan sayım maddeleri.',
    'assets_warrantee_alert' => 'Şu var: gelecek vadede garanti süresi dolmuş varlık sayımı: eşik günler. | Şunlar var: gelecek yıl sona ermesi garantili varlıklar sayılır: eşik günleri.',
    'license_expiring_alert' => 'Şu var: bir sonraki günlerde süren lisans sayımı: eşik günleri. | Şunlar var: bir sonraki günlerde süren sayım lisansları: eşik günleri.',
    'to_reset' => 'Şifre sıfırlamak için :web password, formu doldurun:',
    'type' => 'Tür',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Kullanıcı',
    'username' => 'Kullanıcı Adı',
    'welcome' => 'Hoşgeldiniz, :name',
    'welcome_to' => 'Hoş geldiniz :web!',
    'your_credentials' => 'Snipe-IT Bilgileriniz',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/tr/mail.php <==
<?php

return [
    'a_user_canceled' => 'Bir kullanıcı web sitede öğe talebinden vazgeçti',
    'a_user_requested' => 'Bir kullanıcı websitede bir öğe talebinde bulundu',
    'accessory_name' => 'Aksesuar Adı:',
    'additional_notes' => 'Ek Notlar:',
    'admin_has_created' => 'Bir yönetici sizin için :web site\'de bir hesap oluşturdu.',
    'asset' => 'Varlık:',
    'asset_name' => 'Varlık Adı:',
    'asset_requested' => 'İstenen varlık',
    'asset_tag' => 'Varlık Adı',
    'assigned_to' => 'Atanmış',
    'best_regards' => 'En iyi dileklerimizle,',
    'canceled' => 'İptal edildi:',
    'checkin_date' => 'Giriş Tarihi:',
    'checkout_date' => 'Çıkış Tarihi:',
    'click_to_confirm' => 'Lütfen :hesabınızı: onaylamak için aşağıdaki linke tıklayınız:',
    'click_on_the_link_accessory' => 'Lütfen aşağıdaki bağlantıya tıklayarak aksesuar talebinizi onaylayın.',
    'click_on_the_link_asset' => 'Lütfen aşağıdaki bağlantıya tıklayarak varlık talebinizi onaylayın.',
    'Confirm_Asset_Checkin' => 'Varlık Kabul Onayı',
    'Confirm_Accessory_Checkin' => 'Aksesuar giriş onayı',
    'Confirm_accessory_delivery' => 'Aksesuar teslimat onayı',
    'Confirm_license_delivery' => 'Lisans teslim onayı',
    'Confirm_asset_delivery' => 'Varlık Kabul Onayı',
    'Confirm_consumable_delivery' => 'Sarf malzemesi teslimat onayı',
    'current_QTY' => 'Mevcut miktar',
    'Days' => 'Günler',
    'days' => 'Günler',
    'expecting_checkin_date' => 'Beklenen Giriş Tarihi:',
    'expires' => 'Bitiş',
    'Expiring_Assets_Report' => 'Süresi Dolan Varlık Raporu.',
    'Expiring_Licenses_Report' => 'Süresi Dolan Lisans Raporu.',
    'hello' => 'Merhaba',
    'hi' => 'Merhaba',
    'i_have_read' => 'Okudum ve kullanım şartlarını ve bu varlığı kabul ediyorum.',
    'item' => 'Ürün:',
    'Item_Request_Canceled' => 'Talep İptal Edildi',
    'Item_Requested' => 'Varlık Talep Edildi',
    'link_to_update_password' => 'Şifrenizi güncellemek için aşağıdaki linke tıklayınız :web password:',
    'login_first_admin' => 'Yeni Snipe-IT Kurulumu oturum açma kimlik bilgilerini aşağıdaki gibidir. ',
    'login' => 'Giriş:',
    'Low_Inventory_Report' => 'Düşük Stok Raporu',
    'min_QTY' => 'Min. Miktar',
    'name' => 'Ad',
    'new_item_checked' => 'Yeni varlık altında kullanıma alındı, ayrıntıları aşağıdadır.',
    'password' => 'Parola:',
    'password_reset' => 'Parola Sıfırlama',

    'read_the_terms' => 'Aşağıdaki kullanım koşullarını okuyunuz.',
    'read_the_terms_and_click' => 'Aşağıdaki kullanım şartlarını okuyun ve okumak onaylamak için alt kısımdaki linke tıklayınız
                         ve kullanım şartlarını kabul ve varlık aldık.',
    'requested' => 'Talep Edilen:',
    'reset_link' => 'Parola Sıfırlama Bağlantısı',
    'reset_password' => 'Şifrenizi sıfırlamak için burayı tıklatın:',
    'serial' => 'Seri',
    'supplier' => 'Tedarikçi',
    'tag' => 'Etiket',
    'test_email' => 'Snipe-It Test Maili',
    'test_mail_text' => 'Snipe-IT varlık yönetim sisteminden bir denemedir',
    'the_following_item' => 'Aşağıdaki varlık geri alındı olarak işaretlendi: ',
    'low_inventory_alert' => 'Şu var: Minimum envanterin altında olan veya yakında düşük olacak olan sayı maddesi. | Şunlar var: Minimum envanterin altında olan veya yakında olacak olan sayım maddeleri.',
    'assets_warrantee_alert' => 'Şu var: gelecek vadede garanti süresi dolmuş varlık sayımı: eşik günler. | Şunlar var: gelecek yıl sona ermesi garantili varlıklar sayılır: eşik günleri.',
    'license_expiring_alert' => 'Şu var: bir sonraki günlerde süren lisans sayımı: eşik günleri. | Şunlar var: bir sonraki günlerde süren sayım lisansları: eşik günleri.',
    'to_reset' => 'Şifre sıfırlamak için :web password, formu doldurun:',
    'type' => 'Tür',
    'upcoming-audits' => ':count gün içinde denetime yaklaşan :count varlık var.|Eşik gün içinde denetime yaklaşan :count varlık var.',
    'user' => 'Kullanıcı',
    'username' => 'Kullanıcı Adı',
    'welcome' => 'Hoşgeldiniz, :name',
    'welcome_to' => 'Hoş geldiniz :web!',
    'your_credentials' => 'Snipe-IT Bilgileriniz',
    'Accessory_Checkin_Notification' => 'Aksesuar Zimmet Kabul',
    'Asset_Checkin_Notification' => 'Varlık Zimmet Kabul',
    'License_Checkin_Notification' => 'Lisans Zimmet Kabul',
    'Expected_Checkin_Report' => 'Beklenen varlık iade raporu',
    'Expected_Checkin_Notification' => 'Hatırlatma ::name Son seçim zamanı yaklaşıyor',
    'Expected_Checkin_Date' => 'Size teslim edilen bir varlık :date tarihinde tekrar teslim edilecektir',
    'your_assets' => 'Varlıkları Görüntüleme',
];
